#[cfg(test)]
use super::*;

    #[test]
    fn test_clockwise() {
        let mut current = KartesianDirection::Top;
        let clock = [
            KartesianDirection::Top,
            KartesianDirection::TopRight,
            KartesianDirection::Right,
            KartesianDirection::BottomRight,
            KartesianDirection::Bottom,
            KartesianDirection::BottomLeft,
            KartesianDirection::Left,
            KartesianDirection::TopLeft,
        ];
        for hand in clock {
            assert_eq!(current, hand);
            current = current.clockwise(true);
        }
    }
    #[test]
    fn test_anticlockwise() {
        let mut current = KartesianDirection::Top;
        let clock = [
            KartesianDirection::Top,
            KartesianDirection::TopLeft,
            KartesianDirection::Left,
            KartesianDirection::BottomLeft,
            KartesianDirection::Bottom,
            KartesianDirection::BottomRight,
            KartesianDirection::Right,
            KartesianDirection::TopRight,
        ];
        for hand in clock {
            assert_eq!(current, hand);
            current = current.anticlockwise(true);
        }
    }

    #[test]
    fn test_kartesian_iter() {
        let test: Vec<_> = [
            KartesianDirection::Right,
            KartesianDirection::Top,
            KartesianDirection::Left,
            KartesianDirection::Bottom,
            KartesianDirection::None,
            KartesianDirection::TopLeft,
            KartesianDirection::TopRight,
            KartesianDirection::BottomLeft,
            KartesianDirection::BottomRight,
        ]
        .into();
        let i: Vec<_> = KartesianDirection::iter(true, true, true).collect();
        assert_eq!(i, test);
        let test: Vec<_> = [
            KartesianDirection::Right,
            KartesianDirection::Top,
            KartesianDirection::Left,
            KartesianDirection::Bottom,
            KartesianDirection::TopLeft,
            KartesianDirection::TopRight,
            KartesianDirection::BottomLeft,
            KartesianDirection::BottomRight,
        ]
        .into();
        let i: Vec<_> = KartesianDirection::iter(false, true, true).collect();
        assert_eq!(i, test);
    }

    #[test]
    fn test_diff_dir() {
        const START: Kartesian<u8> = Kartesian::new(1, 1);
        // Top Group
        assert_eq!(KartesianDirection::TopLeft, START.diff(Kartesian::new(0, 0)).1);
        assert_eq!(KartesianDirection::Top, START.diff(Kartesian::new(0, 1)).1);
        assert_eq!(KartesianDirection::TopRight, START.diff(Kartesian::new(0, 2)).1);
        // Same Line
        assert_eq!(KartesianDirection::Left, START.diff(Kartesian::new(1, 0)).1);
        assert_eq!(KartesianDirection::None, START.diff(Kartesian::new(1, 1)).1);
        assert_eq!(KartesianDirection::Right, START.diff(Kartesian::new(1, 2)).1);
        // Below/Bottom Line
        assert_eq!(KartesianDirection::BottomLeft, START.diff(Kartesian::new(2, 0)).1);
        assert_eq!(KartesianDirection::Bottom, START.diff(Kartesian::new(2, 1)).1);
        assert_eq!(KartesianDirection::BottomRight, START.diff(Kartesian::new(2, 2)).1);
    }